@@ -59,6 +59,7 @@ import java.io.UnsupportedEncodingException;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.text.DateFormat;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Locale;
 import java.util.Properties;
@@ -138,7 +139,9 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.TransportAuth;
 import com.openexchange.oauth.API;
+import com.openexchange.oauth.DefaultOAuthAccount;
 import com.openexchange.oauth.OAuthAccount;
+import com.openexchange.oauth.OAuthConstants;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthUtil;
@@ -294,7 +297,7 @@ public class GmailSendTransport extends MailTransport {
                     if (null != oauthService) {
                         OAuthAccount oAuthAccount;
                         try {
-                            oAuthAccount = oauthService.getAccount(account.getTransportOAuthId(), session, session.getUserId(), session.getContextId());
+                            oAuthAccount = oauthService.getAccount(session, account.getTransportOAuthId());
                         } catch (Exception x) {
                             LOG.warn("Failed to load transport-associated OAuth account", x);
                             oAuthAccount = null;
@@ -314,7 +317,7 @@ public class GmailSendTransport extends MailTransport {
                         OAuthService oauthService = Services.optService(OAuthService.class);
                         if (null != oauthService) {
                             try {
-                                OAuthAccount oAuthAccount = oauthService.getAccount(mailAccount.getMailOAuthId(), session, session.getUserId(), session.getContextId());
+                                OAuthAccount oAuthAccount = oauthService.getAccount(session, mailAccount.getMailOAuthId());
                                 throw MailExceptionCode.MAIL_TRANSPORT_DISABLED_OAUTH.create(gmailSendConfig.getServer(), gmailSendConfig.getLogin(), I(session.getUserId()), I(session.getContextId()), oAuthAccount.getDisplayName());
                             } catch (Exception x) {
                                 LOG.warn("Failed to load mail-associated OAuth account", x);
@@ -368,6 +371,13 @@ public class GmailSendTransport extends MailTransport {
         // Verify that scopes are available and enabled
         OAuthUtil.checkScopesAvailableAndEnabled(account, session, scopes);
 
+        // Verify if the account has the user identity set, lazy update
+        if (Strings.isEmpty(account.getUserIdentity())) {
+            String userIdentity = account.getMetaData().getUserIdentity(session, account.getId(), account.getToken(), account.getSecret());
+            ((DefaultOAuthAccount) account).setUserIdentity(userIdentity);
+            oauthService.updateAccount(session, account.getId(), Collections.singletonMap(OAuthConstants.ARGUMENT_IDENTITY, userIdentity));
+        }
+
         // Other checks?
     }
 
@@ -599,7 +609,7 @@ public class GmailSendTransport extends MailTransport {
 
             // Set header
             mimeMessage.setHeader(MessageHeaders.HDR_X_PRIORITY, "3 (normal)");
-            mimeMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "Medium");
+            mimeMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "Normal");
 
             // Subject
             final Locale locale = UserStorage.getInstance().getUser(session.getUserId(), ctx).getLocale();
@@ -765,6 +775,14 @@ public class GmailSendTransport extends MailTransport {
         GmailAccess gmailAccess = null;
         Exception exception = null;
         try {
+            // Check if security settings are given and if properly handled
+            if (securitySettings != null && securitySettings.anythingSet()) {
+                if (false == listenerChain.checkSettings(securitySettings, session)) {
+                    // Security settings not considered
+                    throw GmailSendExceptionCode.INTERNAL_ERROR.create("Security settings available, but not handled. Guard-backend-plugin installed?");
+                }
+            }
+
             // Check listener chain
             Result result = listenerChain.onBeforeMessageTransport(messageToSend, recipientz, securitySettings, session);
 
@@ -1013,9 +1031,16 @@ public class GmailSendTransport extends MailTransport {
         {
             final String str = mimeMessage.getHeader("Disposition-Notification-To", null);
             if (!com.openexchange.java.Strings.isEmpty(str)) {
-                final InternetAddress[] addresses = QuotedInternetAddress.parse(str, false);
-                checkRecipients(addresses);
-                mimeMessage.setHeader("Disposition-Notification-To", addresses[0].toString());
+                if ("true".equalsIgnoreCase(str)) {
+                    Address[] fromAddresses = mimeMessage.getFrom();
+                    if (fromAddresses.length > 0 && fromAddresses[0] != null) {
+                        mimeMessage.setHeader("Disposition-Notification-To", fromAddresses[0].toString());
+                    }
+                } else {
+                    final InternetAddress[] addresses = QuotedInternetAddress.parse(str, false);
+                    checkRecipients(addresses);
+                    mimeMessage.setHeader("Disposition-Notification-To", addresses[0].toString());
+                }
             }
         }
     }
