@@ -51,6 +51,8 @@
 package com.openexchange.google.api.client;
 
 import java.security.GeneralSecurityException;
+import java.util.ArrayList;
+import java.util.List;
 import javax.net.ssl.SSLHandshakeException;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -65,7 +67,6 @@ import com.google.api.client.json.JsonFactory;
 import com.google.api.client.json.jackson2.JacksonFactory;
 import com.openexchange.cluster.lock.ClusterLockService;
 import com.openexchange.cluster.lock.ClusterTask;
-import com.openexchange.cluster.lock.policies.ExponentialBackOffRetryPolicy;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
@@ -74,11 +75,12 @@ import com.openexchange.exception.OXException;
 import com.openexchange.google.api.client.services.Services;
 import com.openexchange.java.Strings;
 import com.openexchange.net.ssl.exception.SSLExceptionCode;
-import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.AbstractReauthorizeClusterTask;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.OAuthService;
+import com.openexchange.policy.retry.ExponentialBackOffRetryPolicy;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.session.Session;
 
@@ -134,29 +136,42 @@ public class GoogleApiClients {
 
         // Get default Google account
         OAuthAccount defaultAccount = oAuthService.getDefaultAccount(KnownApi.GOOGLE, session);
-
-        if (reacquireIfExpired) {
-            try {
-                // Create Scribe Google OAuth service
-                final ServiceBuilder serviceBuilder = new ServiceBuilder().provider(Google2Api.class);
-                serviceBuilder.apiKey(defaultAccount.getMetaData().getAPIKey(session)).apiSecret(defaultAccount.getMetaData().getAPISecret(session));
-                Google2Api.GoogleOAuth2Service scribeOAuthService = (Google2Api.GoogleOAuth2Service) serviceBuilder.build();
-
-                // Check expiry
-                int expiry = scribeOAuthService.getExpiry(defaultAccount.getToken());
-                if (expiry < REFRESH_THRESHOLD) {
-                    // Less than 1 minute to live -> refresh token!
-                    ClusterLockService clusterLockService = Services.getService(ClusterLockService.class);
-                    defaultAccount = clusterLockService.runClusterTask(new GoogleReauthorizeClusterTask(session, defaultAccount), new ExponentialBackOffRetryPolicy());
-                }
-            } catch (org.scribe.exceptions.OAuthException e) {
-                throw handleScribeOAuthException(e, defaultAccount, session);
-            }
-        }
-
+        defaultAccount = reacquireIfExpired(session, reacquireIfExpired, defaultAccount);
         return defaultAccount;
     }
 
+    /**
+     * Check if the OAuth token of the specified {@link OAuthAccount} was expired and re-acquire if necessary
+     *
+     * @param session The groupware {@link Session}
+     * @param reacquireIfExpired perform the requisition check
+     * @param oauthAccount The {@link OAuthAccount}
+     * @return The {@link OAuthAccount} with the (renewed) token
+     * @throws OXException if an error is occurred
+     */
+    public static OAuthAccount reacquireIfExpired(final Session session, final boolean reacquireIfExpired, OAuthAccount oauthAccount) throws OXException {
+        if (!reacquireIfExpired) {
+            return oauthAccount;
+        }
+        try {
+            // Create Scribe Google OAuth service
+            final ServiceBuilder serviceBuilder = new ServiceBuilder().provider(Google2Api.class);
+            serviceBuilder.apiKey(oauthAccount.getMetaData().getAPIKey(session)).apiSecret(oauthAccount.getMetaData().getAPISecret(session));
+            Google2Api.GoogleOAuth2Service scribeOAuthService = (Google2Api.GoogleOAuth2Service) serviceBuilder.build();
+
+            // Check expiry
+            int expiry = scribeOAuthService.getExpiry(oauthAccount.getToken());
+            if (expiry < REFRESH_THRESHOLD) {
+                // Less than 1 minute to live -> refresh token!
+                ClusterLockService clusterLockService = Services.getService(ClusterLockService.class);
+                oauthAccount = clusterLockService.runClusterTask(new GoogleReauthorizeClusterTask(session, oauthAccount), new ExponentialBackOffRetryPolicy());
+            }
+        } catch (org.scribe.exceptions.OAuthException e) {
+            throw handleScribeOAuthException(e, oauthAccount, session);
+        }
+        return oauthAccount;
+    }
+
     /**
      * Gets the denoted Google OAuth account.
      * <p>
@@ -189,26 +204,9 @@ public class GoogleApiClients {
         }
 
         // Get default Google account
-        OAuthAccount googleAccount = oAuthService.getAccount(accountId, session, session.getUserId(), session.getContextId());
+        OAuthAccount googleAccount = oAuthService.getAccount(session, accountId);
 
-        if (reacquireIfExpired) {
-            try {
-                // Create Scribe Google OAuth service
-                final ServiceBuilder serviceBuilder = new ServiceBuilder().provider(Google2Api.class);
-                serviceBuilder.apiKey(googleAccount.getMetaData().getAPIKey(session)).apiSecret(googleAccount.getMetaData().getAPISecret(session));
-                Google2Api.GoogleOAuth2Service scribeOAuthService = (Google2Api.GoogleOAuth2Service) serviceBuilder.build();
-
-                // Check expiry
-                int expiry = scribeOAuthService.getExpiry(googleAccount.getToken());
-                if (expiry < REFRESH_THRESHOLD) {
-                    // Less than 1 minute to live -> refresh token!
-                    ClusterLockService clusterLockService = Services.getService(ClusterLockService.class);
-                    googleAccount = clusterLockService.runClusterTask(new GoogleReauthorizeClusterTask(session, googleAccount), new ExponentialBackOffRetryPolicy());
-                }
-            } catch (org.scribe.exceptions.OAuthException e) {
-                throw handleScribeOAuthException(e, googleAccount, session);
-            }
-        }
+        googleAccount = reacquireIfExpired(session, reacquireIfExpired, googleAccount);
 
         return googleAccount;
     }
@@ -313,7 +311,10 @@ public class GoogleApiClients {
 
     static OXException handleScribeOAuthException(OAuthException e, OAuthAccount googleAccount, Session session) {
         if (ExceptionUtils.isEitherOf(e, SSLHandshakeException.class)) {
-            return SSLExceptionCode.UNTRUSTED_CERTIFICATE.create(e, "www.googleapis.com");
+            List<Object> displayArgs = new ArrayList<>(2);
+            displayArgs.add(SSLExceptionCode.extractArgument(e, "fingerprint"));
+            displayArgs.add("www.googleapis.com");
+            return SSLExceptionCode.UNTRUSTED_CERTIFICATE.create(e, displayArgs.toArray(new Object[] {}));
         }
 
         String exMessage = e.getMessage();
@@ -321,13 +322,13 @@ public class GoogleApiClients {
         if (Strings.isEmpty(errorMsg)) {
             return OAuthExceptionCodes.OAUTH_ERROR.create(e, exMessage);
         }
-        if (exMessage.contains("invalid_grant")) {
+        if (exMessage.contains("invalid_grant") || exMessage.contains("deleted_client")) {
             if (null != googleAccount) {
                 return OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(e, googleAccount.getDisplayName(), googleAccount.getId(), session.getUserId(), session.getContextId());
             }
             return OAuthExceptionCodes.INVALID_ACCOUNT.create(e, new Object[0]);
         }
-        return OAuthExceptionCodes.OAUTH_ERROR.create(exMessage, e);
+        return OAuthExceptionCodes.OAUTH_ERROR.create(e, exMessage);
     }
 
     private static String parseErrorFrom(String message) {
@@ -386,6 +387,8 @@ public class GoogleApiClients {
             // Initialize transport
             NetHttpTransport transport = new NetHttpTransport.Builder().doNotValidateCertificate().build();
 
+            googleOAuthAccount = reacquireIfExpired(session, true, googleOAuthAccount);
+
             // Build credentials
             return new GoogleCredential.Builder().setClientSecrets(googleOAuthAccount.getMetaData().getAPIKey(session), googleOAuthAccount.getMetaData().getAPISecret(session)).setJsonFactory(JSON_FACTORY).setTransport(transport).build().setRefreshToken(googleOAuthAccount.getSecret()).setAccessToken(googleOAuthAccount.getToken());
         } catch (GeneralSecurityException e) {
