@@ -53,6 +53,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import org.scribe.builder.api.Api;
+import org.scribe.model.Verb;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.impl.AbstractExtendedScribeAwareOAuthServiceMetaData;
@@ -65,6 +66,9 @@ import com.openexchange.server.ServiceLookup;
  */
 public class DropboxOAuthServiceMetaData extends AbstractExtendedScribeAwareOAuthServiceMetaData {
 
+    private static final String IDENTITY_URL = "https://api.dropboxapi.com/2/users/get_current_account";
+    private static final String IDENTITY_FIELD_NAME = "account_id";
+
     /**
      * Initializes a new {@link DropboxOAuthServiceMetaData}.
      */
@@ -99,4 +103,50 @@ public class DropboxOAuthServiceMetaData extends AbstractExtendedScribeAwareOAut
         return propertyNames;
     }
 
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityMethod()
+     */
+    @Override
+    public Verb getIdentityHTTPMethod() {
+        return Verb.POST;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityURL()
+     */
+    @Override
+    public String getIdentityURL(String accessToken) {
+        return IDENTITY_URL;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityPattern()
+     */
+    @Override
+    public String getIdentityFieldName() {
+        return IDENTITY_FIELD_NAME;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.AbstractScribeAwareOAuthServiceMetaData#getContentType()
+     */
+    @Override
+    public String getContentType() {
+        // Empty content-type otherwise the getUserIdentity call will fail.
+        // 
+        // The scribe library it tries to append a body when the request verb is
+        // set to POST. The Dropbox API is picky and if the 'Content-Type' is
+        // set to 'application/json', it then tries to interpret the body that is send
+        // with the request. However, when getting the user's identity via the getIdentityURL link
+        // no body is required... and none is sent... hence the fail on Dropbox's side.
+        return EMPTY_CONTENT_TYPE;
+    }
 }
