@@ -82,33 +82,33 @@ public final class OSGiOAuthService extends AbstractOSGiDelegateService<OAuthSer
     }
 
     @Override
-    public OAuthAccount createAccount(final String serviceMetaData, final Map<String, Object> arguments, final int user, final int contextId, Set<OAuthScope> scopes) throws OXException {
-        return getService0().createAccount(serviceMetaData, arguments, user, contextId, scopes);
+    public OAuthAccount createAccount(Session session, final String serviceMetaData, Set<OAuthScope> scopes, final Map<String, Object> arguments) throws OXException {
+        return getService0().createAccount(session, serviceMetaData, scopes, arguments);
     }
 
     @Override
-    public OAuthAccount createAccount(final String serviceMetaData, final OAuthInteractionType type, final Map<String, Object> arguments, final int user, final int contextId, Set<OAuthScope> scopes) throws OXException {
-        return getService0().createAccount(serviceMetaData, type, arguments, user, contextId, scopes);
+    public OAuthAccount createAccount(Session session, final String serviceMetaData, Set<OAuthScope> scopes, final OAuthInteractionType type, final Map<String, Object> arguments) throws OXException {
+        return getService0().createAccount(session, serviceMetaData, scopes, type, arguments);
     }
 
     @Override
-    public void deleteAccount(final int accountId, final int user, final int contextId) throws OXException {
-        getService0().deleteAccount(accountId, user, contextId);
+    public void deleteAccount(Session session, final int accountId) throws OXException {
+        getService0().deleteAccount(session, accountId);
     }
 
     @Override
-    public OAuthAccount getAccount(final int accountId, final Session session, final int user, final int contextId) throws OXException {
-        return getService0().getAccount(accountId, session, user, contextId);
+    public OAuthAccount getAccount(final Session session, final int accountId) throws OXException {
+        return getService0().getAccount(session, accountId);
     }
 
     @Override
-    public List<OAuthAccount> getAccounts(final Session session, final int user, final int contextId) throws OXException {
-        return getService0().getAccounts(session, user, contextId);
+    public List<OAuthAccount> getAccounts(final Session session) throws OXException {
+        return getService0().getAccounts(session);
     }
 
     @Override
-    public List<OAuthAccount> getAccounts(final String serviceMetaData, final Session session, final int user, final int contextId) throws OXException {
-        return getService0().getAccounts(serviceMetaData, session, user, contextId);
+    public List<OAuthAccount> getAccounts(Session session, String serviceMetaData) throws OXException {
+        return getService0().getAccounts(session, serviceMetaData);
     }
 
     @Override
@@ -121,22 +121,32 @@ public final class OSGiOAuthService extends AbstractOSGiDelegateService<OAuthSer
     }
 
     @Override
-    public OAuthInteraction initOAuth(final String serviceMetaData, final String callbackUrl, final HostInfo host, final Session session, Set<OAuthScope> scopes) throws OXException {
-        return getService0().initOAuth(serviceMetaData, callbackUrl, host, session, scopes);
+    public OAuthInteraction initOAuth(final Session session, final String serviceMetaData, final String callbackUrl, final HostInfo host, Set<OAuthScope> scopes) throws OXException {
+        return getService0().initOAuth(session, serviceMetaData, callbackUrl, host, scopes);
     }
 
     @Override
-    public void updateAccount(final int accountId, final Map<String, Object> arguments, final int user, final int contextId) throws OXException {
-        getService0().updateAccount(accountId, arguments, user, contextId);
+    public void updateAccount(Session session, final int accountId, final Map<String, Object> arguments) throws OXException {
+        getService0().updateAccount(session, accountId, arguments);
     }
 
     @Override
-    public OAuthAccount updateAccount(final int accountId, final String serviceMetaData, final OAuthInteractionType type, final Map<String, Object> arguments, final int user, final int contextId, Set<OAuthScope> scopes) throws OXException {
-        return getService0().updateAccount(accountId, serviceMetaData, type, arguments, user, contextId, scopes);
+    public OAuthAccount updateAccount(Session session, final int accountId, final String serviceMetaData, final OAuthInteractionType type, final Map<String, Object> arguments, Set<OAuthScope> scopes) throws OXException {
+        return getService0().updateAccount(session, accountId, serviceMetaData, type, arguments, scopes);
     }
 
     @Override
     public OAuthAccount getDefaultAccount(API api, Session session) throws OXException {
-        return getService0().getDefaultAccount(api, null);
+        return getService0().getDefaultAccount(api, session);
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.OAuthService#upsertAccount(java.lang.String, com.openexchange.oauth.OAuthInteractionType, java.util.Map, int, int, java.util.Set)
+     */
+    @Override
+    public OAuthAccount upsertAccount(Session session, String serviceMetaData, int accountId, OAuthInteractionType type, Map<String, Object> arguments, Set<OAuthScope> scopes) throws OXException {
+        return getService0().upsertAccount(session, serviceMetaData, accountId, type, arguments, scopes);
     }
 }
