@@ -49,13 +49,11 @@
 
 package com.openexchange.oauth.json.proxy;
 
-import java.util.Arrays;
-import java.util.Collection;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
-import com.openexchange.oauth.http.OAuthHTTPClientFactory;
 import com.openexchange.oauth.OAuthService;
+import com.openexchange.oauth.http.OAuthHTTPClientFactory;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
 /**
@@ -69,11 +67,6 @@ public class OAuthProxyActionFactory implements AJAXActionServiceFactory {
         proxyAction = new OAuthProxyAction(service, clients);
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return Arrays.asList("PUT", "POST");
-    }
-
     @Override
     public AJAXActionService createActionService(String action) throws OXException {
         if (!"PUT".equals(action) && !"POST".equals(action)) {
