@@ -51,6 +51,9 @@ package com.openexchange.xing.access.internal;
 
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
+import com.openexchange.oauth.KnownApi;
+import com.openexchange.oauth.access.OAuthAccessRegistry;
+import com.openexchange.oauth.access.OAuthAccessRegistryService;
 import com.openexchange.sessiond.SessiondEventConstants;
 
 /**
@@ -81,7 +84,9 @@ public final class XingEventHandler implements EventHandler {
                 if (null != contextId) {
                     Integer userId = (Integer) event.getProperty(SessiondEventConstants.PROP_USER_ID);
                     if (null != userId) {
-                        if (XingOAuthAccessRegistry.getInstance().removeAccessWhenNoActiveSession(userId, contextId)) {
+                        OAuthAccessRegistryService registryService = Services.getService(OAuthAccessRegistryService.class);
+                        OAuthAccessRegistry registry = registryService.get(KnownApi.XING.getFullName());
+                        if (registry.removeIfLast(contextId, userId)) {
                             LOG.debug("XING session removed for user {} in context {}", userId, contextId);
                         }
                     }
